==> KidozSDK-0.1.3-sources.jar: com/kidoz/sdk/api/FeedViewDialog.java <==
package com.kidoz.sdk.api;

import android.content.Context;
import android.content.DialogInterface;
import android.content.pm.ActivityInfo;
import android.content.res.Configuration;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.View;

import com.kidoz.events.EventManager;
import com.kidoz.events.EventParameters;
import com.kidoz.sdk.api.general.BaseDialog;
import com.kidoz.sdk.api.general.enums.ContentType;
import com.kidoz.sdk.api.interfaces.IOnFeedViewEventListener;
import com.kidoz.sdk.api.structure.ContentData;
import com.kidoz.sdk.api.structure.ContentItem;
import com.kidoz.sdk.api.ui_views.ContentPanelView;
import com.kidoz.sdk.api.ui_views.FeedFullVeiw;

/**
 * Created by Eugine on 10/1/2015.
 */
class FeedViewDialog extends BaseDialog
{

    private static final String SAVE_DATA_INSTANCE_KEY = "SAVE_DATA_INSTANCE_KEY";
    private static final String SAVE_ORIGINAL_ORIENTATION_KEY = "SAVE_ORIGINAL_ORIENTATION_KEY";

    private FeedFullVeiw mFeedFullVeiw;
    private ContentData mContentData = null;
    // Close button click listener
    private View.OnClickListener mCloseBtnClickListener = null;

    private int mCurrentOrientationState;

    private long mEventID;
    private boolean mImpressionServed;
    private IOnFeedViewEventListener mOnInterstitialViewEventListener;

    public FeedViewDialog(Context context)
    {
        super(context, android.R.style.Theme_Black_NoTitleBar_Fullscreen);
        setCancelable(false);

        // Init back button listener
        setOnKeyListener(new DialogInterface.OnKeyListener()
        {
            @Override public boolean onKey(DialogInterface dialog, int keyCode, KeyEvent event)
            {
                boolean result = true;
                if (event.getAction() == KeyEvent.ACTION_DOWN)
                {
                    if (keyCode == KeyEvent.KEYCODE_BACK)
                    {
                        if (mFeedFullVeiw != null && mFeedFullVeiw.getViewBottomBar().isAboutViewVisible())
                        {
                            mFeedFullVeiw.getViewBottomBar().hideAboutView();
                        }
                        else
                        {
                            if (mOnInterstitialViewEventListener != null)
                            {
                                mOnInterstitialViewEventListener.onDismissView();
                            }
                            closeDialog();
                        }
                    }
                }
                return result;
            }
        });
    }

    @Override protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);

        if (savedInstanceState != null && savedInstanceState.containsKey(SAVE_ORIGINAL_ORIENTATION_KEY))
        {
            mCurrentOrientationState = savedInstanceState.getInt(SAVE_ORIGINAL_ORIENTATION_KEY);
        }
        else
        {
            mCurrentOrientationState = mCallingActivity.getResources().getConfiguration().orientation;
            mCallingActivity.setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR);
        }

        mImpressionServed = false;

        // Restore current view state data in case the fragment was destroyed due to going offscreen
        if (mContentData == null && savedInstanceState != null && savedInstanceState.containsKey(SAVE_DATA_INSTANCE_KEY))
        {
            mContentData = (ContentData) savedInstanceState.get(SAVE_DATA_INSTANCE_KEY);
        }

        mFeedFullVeiw = new FeedFullVeiw(mCallingActivity);
        mFeedFullVeiw.setOnContentItemClickListener(new ContentPanelView.IOnContentItemClickListener()
        {
            @Override public void onItemClick(ContentItem contentItem, int postion)
            {
                if (contentItem != null && contentItem.getContentType() != null && contentItem.getContentType() != ContentType.NONE)
                {
                    // Handle content item click
                    ContentExecutionHandler.handleContentItemClick(mCallingActivity, contentItem, postion);
                }
            }
        });

        mFeedFullVeiw.setOnCloseButtonClickListenr(mCloseBtnClickListener);
        mFeedFullVeiw.setContentDataAndRefresh(mContentData);

        setContentView(mFeedFullVeiw);
    }

    protected void setContentData(ContentData contentData)
    {
        mContentData = contentData;
        if (mFeedFullVeiw != null)
        {
            mFeedFullVeiw.setContentDataAndRefresh(mContentData);
        }
    }

    /**
     * Set on close button click listener
     *
     * @param clickListenr click listener
     */
    protected void setOnCloseButtonClickListenr(View.OnClickListener clickListenr)
    {
        mCloseBtnClickListener = clickListenr;
        if (mFeedFullVeiw != null)
        {
            mFeedFullVeiw.setOnCloseButtonClickListenr(mCloseBtnClickListener);
        }
    }


    @Override public Bundle onSaveInstanceState()
    {
        Bundle bundle = super.onSaveInstanceState();
        if (mContentData != null)
        {
            bundle.putSerializable(SAVE_DATA_INSTANCE_KEY, mContentData);
            bundle.putInt(SAVE_ORIGINAL_ORIENTATION_KEY, mCurrentOrientationState);
        }
        return bundle;
    }

    @Override public void onRestoreInstanceState(Bundle savedInstanceState)
    {
        super.onRestoreInstanceState(savedInstanceState);

    }

    @Override protected void closeDialog()
    {

        mContentData = null;

        super.closeDialog();

        // Restore previous orientation
        restoreUserOriginalOrientation();
    }

    @Override protected void openDialog()
    {
        if (KidozSDK.isInitialised())
        {
            super.openDialog();
            EventManager.getInstance().logEvent(mCallingActivity, EventManager.LOG_CRITICAL_LEVEL, EventParameters.CATEGORY_SPONSORED_CONTENT, EventParameters.ACTION_WIDGET_VIEW, EventParameters.FEED_VIEW);
        }
    }

    /**
     * Restore user original orientation
     */
    private void restoreUserOriginalOrientation()
    {
        if (mCallingActivity != null && mCallingActivity.isFinishing() == false)
        {
            switch (mCurrentOrientationState)
            {
                case Configuration.ORIENTATION_LANDSCAPE:
                {
                    mCallingActivity.setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR_LANDSCAPE);
                    break;
                }

                case Configuration.ORIENTATION_PORTRAIT:
                {
                    mCallingActivity.setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR_PORTRAIT);
                    break;
                }
                case Configuration.ORIENTATION_UNDEFINED:
                {
                    mCallingActivity.setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR);
                    break;
                }
            }
        }
    }

    public void setOnInterstitialViewEventListener(IOnFeedViewEventListener onInterstitialViewEventListener)
    {
        mOnInterstitialViewEventListener = onInterstitialViewEventListener;
    }
}

==> KidozSDK-0.1.4-sources.jar: com/kidoz/sdk/api/FeedViewDialog.java <==
package com.kidoz.sdk.api;

import android.content.Context;
import android.content.DialogInterface;
import android.content.pm.ActivityInfo;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.View;

import com.kidoz.events.EventManager;
import com.kidoz.events.EventParameters;
import com.kidoz.sdk.api.general.BaseDialog;
import com.kidoz.sdk.api.general.enums.ContentType;
import com.kidoz.sdk.api.interfaces.IOnFeedViewEventListener;
import com.kidoz.sdk.api.structure.ContentData;
import com.kidoz.sdk.api.structure.ContentItem;
import com.kidoz.sdk.api.ui_views.ContentPanelView;
import com.kidoz.sdk.api.ui_views.FeedFullVeiw;

/**
 * Created by Eugine on 10/1/2015.
 */
class FeedViewDialog extends BaseDialog
{

    private static final String SAVE_DATA_INSTANCE_KEY = "SAVE_DATA_INSTANCE_KEY";
    private static final String SAVE_ORIGINAL_ORIENTATION_KEY = "SAVE_ORIGINAL_ORIENTATION_KEY";

    private FeedFullVeiw mFeedFullVeiw;
    private ContentData mContentData = null;
    // Close button click listener
    private View.OnClickListener mCloseBtnClickListener = null;

    private long mEventID;
    private boolean mImpressionServed;
    private IOnFeedViewEventListener mOnInterstitialViewEventListener;

    public FeedViewDialog(Context context)
    {
        super(context, android.R.style.Theme_Black_NoTitleBar_Fullscreen);
        setCancelable(false);

        // Init back button listener
        setOnKeyListener(new DialogInterface.OnKeyListener()
        {
            @Override public boolean onKey(DialogInterface dialog, int keyCode, KeyEvent event)
            {
                boolean result = true;
                if (event.getAction() == KeyEvent.ACTION_DOWN)
                {
                    if (keyCode == KeyEvent.KEYCODE_BACK)
                    {
                        if (mFeedFullVeiw != null && mFeedFullVeiw.getViewBottomBar().isAboutViewVisible())
                        {
                            mFeedFullVeiw.getViewBottomBar().hideAboutView();
                        }
                        else
                        {
                            if (mOnInterstitialViewEventListener != null)
                            {
                                mOnInterstitialViewEventListener.onDismissView();
                            }
                            closeDialog();
                        }
                    }
                }
                return result;
            }
        });
    }

    @Override protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);

        if (savedInstanceState != null && savedInstanceState.containsKey(SAVE_ORIGINAL_ORIENTATION_KEY))
        {
            mCurrentOrientationState = savedInstanceState.getInt(SAVE_ORIGINAL_ORIENTATION_KEY);
        }
        else
        {
            mCurrentOrientationState = mCallingActivity.getResources().getConfiguration().orientation;
            mCallingActivity.setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR);
        }

        mImpressionServed = false;

        // Restore current view state data in case the fragment was destroyed due to going offscreen
        if (mContentData == null && savedInstanceState != null && savedInstanceState.containsKey(SAVE_DATA_INSTANCE_KEY))
        {
            mContentData = (ContentData) savedInstanceState.get(SAVE_DATA_INSTANCE_KEY);
        }

        mFeedFullVeiw = new FeedFullVeiw(mCallingActivity);
        mFeedFullVeiw.setOnContentItemClickListener(new ContentPanelView.IOnContentItemClickListener()
        {
            @Override public void onItemClick(ContentItem contentItem, int postion)
            {
                if (contentItem != null && contentItem.getContentType() != null && contentItem.getContentType() != ContentType.NONE)
                {
                    // Handle content item click
                    ContentExecutionHandler.handleContentItemClick(mCallingActivity, contentItem, postion, false);
                }
            }
        });

        mFeedFullVeiw.setOnCloseButtonClickListenr(mCloseBtnClickListener);
        mFeedFullVeiw.setContentDataAndRefresh(mContentData);

        setContentView(mFeedFullVeiw);

        mFeedFullVeiw.showLoadingProgressView(true);

        setOnDismissListener(new OnDismissListener()
        {
            @Override public void onDismiss(DialogInterface dialog)
            {

                // Restore previous orientation
                restoreUserOriginalOrientation();
            }
        });
    }

    protected void setContentData(ContentData contentData)
    {
        mContentData = contentData;
        if (mFeedFullVeiw != null)
        {
            mFeedFullVeiw.showLoadingProgressView(false);
            mFeedFullVeiw.setContentDataAndRefresh(mContentData);
        }
    }

    /**
     * Set on close button click listener
     *
     * @param clickListenr click listener
     */
    protected void setOnCloseButtonClickListenr(View.OnClickListener clickListenr)
    {
        mCloseBtnClickListener = clickListenr;
        if (mFeedFullVeiw != null)
        {
            mFeedFullVeiw.setOnCloseButtonClickListenr(mCloseBtnClickListener);
        }
    }


    @Override public Bundle onSaveInstanceState()
    {
        Bundle bundle = super.onSaveInstanceState();
        if (mContentData != null)
        {
            bundle.putSerializable(SAVE_DATA_INSTANCE_KEY, mContentData);
            bundle.putInt(SAVE_ORIGINAL_ORIENTATION_KEY, mCurrentOrientationState);
        }
        return bundle;
    }

    @Override public void onRestoreInstanceState(Bundle savedInstanceState)
    {
        super.onRestoreInstanceState(savedInstanceState);

    }

    @Override public void closeDialog()
    {

        mContentData = null;
        super.closeDialog();
    }

    @Override public void openDialog()
    {
        if (KidozSDK.isInitialised())
        {
            super.openDialog();
            EventManager.getInstance().logEvent(mCallingActivity, EventManager.LOG_CRITICAL_LEVEL, EventParameters.CATEGORY_SPONSORED_CONTENT, EventParameters.ACTION_WIDGET_VIEW, EventParameters.FEED_VIEW);
        }
    }

    public void setOnInterstitialViewEventListener(IOnFeedViewEventListener onInterstitialViewEventListener)
    {
        mOnInterstitialViewEventListener = onInterstitialViewEventListener;
    }
}
